predictCopulaGAMM: Conditional expectation for a copula-based estimation of mixed regression models for continuous or discrete response
Description
Compute the conditional expectation of a copula-based 2-level hierarchical model for disctrete response.
Usage
predictCopulaGAMM(object, newdata, m = 100)
Value
mest
Conditional expectations (conditional probabilities for the multinomial case
Arguments
object
Object of class ``CopulaGAMM`` generated by EstCopulaGAMM.
newdata
List of variables for be predicted (``clu`` for clusters, ``xc`` for the copula covariates, and ``xm`` for the margins covariates). The covariates can be NULL.
m
Number of points for the numerical integration in the discrete case (default is 100).
Author
Pavel Krupskii and Bruno N. Remillard, January 20, 2023